:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _v0_5:

Version 0.5
===========

This release includes a number of enhancements and bug fixes, mainly
to the :class:`treeple.tree.MultiViewDecisionTreeClassifier`. Most notably,
the ``max_features`` argument now supports an array of values, which
applies a different ``max_features`` argument per feature view.

Changelog
---------

- |Enhancement| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now
  rounds up the number of features to split on to the nearest integer when
  applying ``max_features`` to each feature view, by `Adam Li`_ (:pr:`#183`).
- |Feature| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now
  supports an array passed in for ``max_features``, which applies a different
  max_features argument per view, by `Adam Li`_ (:pr:`#183`).
- |Fix| :class:`treeple.tree.MultiViewDecisionTreeClassifier` now correctly
  handles the case where there is one feature view that is exhausted, and
  another that is not for ``apply_max_features_per_feature_set = False``,
  by `Adam Li`_ (:pr:`#183`).
- |Fix| ``treeple.stats.FeatureImportanceForestClassifier`` now correctly passes
  metric kwargs to the null distribution function, by `Adam Li`_ (:pr:`#183`).

Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_

